@@ -1,7 +1,7 @@
 package Bencher::Scenario::ZodiacModules;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,7 +40,7 @@ Bencher::Scenario::ZodiacModules - Benchmark various zodiac modules
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::ZodiacModules (from Perl distribution Bencher-Scenario-ZodiacModules), released on 2016-06-26.
+This document describes version 0.05 of Bencher::Scenario::ZodiacModules (from Perl distribution Bencher-Scenario-ZodiacModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -54,6 +54,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -106,35 +110,36 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m ZodiacModules >>):
 
- +-------------------------------------------+-----------+------------+------------+--------+---------+
- | participant                               | rate (/s) | time (μs)  | vs_slowest | errors | samples |
- +-------------------------------------------+-----------+------------+------------+--------+---------+
- | DateTime::Event::Zodiac::zodiac_date_name |      1270 | 786        |      1     |  6e-07 |      23 |
- | Zodiac::Chinese::Table::chinese_zodiac    |   1016040 |   0.984212 |    798.925 |  0     |      25 |
- | Zodiac::Tiny::zodiac_of                   |   1217160 |   0.821582 |    957.07  |  0     |      24 |
- | Zodiac::Chinese::chinese_zodiac           |   2409930 |   0.41495  |   1894.96  |  0     |      20 |
- +-------------------------------------------+-----------+------------+------------+--------+---------+
+ #table1#
+ +-------------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                               | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-------------------------------------------+-----------+-----------+------------+---------+---------+
+ | DateTime::Event::Zodiac::zodiac_date_name |       920 |   1100    |          1 |   4e-06 |      26 |
+ | Zodiac::Chinese::Table::chinese_zodiac    |    727000 |      1.37 |        789 | 7.6e-10 |      26 |
+ | Zodiac::Tiny::zodiac_of                   |    897000 |      1.11 |        973 | 4.2e-10 |      20 |
+ | Zodiac::Chinese::chinese_zodiac           |   1760000 |      0.57 |       1900 | 1.7e-10 |      30 |
+ +-------------------------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m ZodiacModules --module-startup >>):
 
- +-------------------------+-----------+------------------------+------------+---------+---------+
- | participant             | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +-------------------------+-----------+------------------------+------------+---------+---------+
- | DateTime::Event::Zodiac |      39   |                   36.5 |        1   | 9.1e-05 |      22 |
- | Zodiac::Chinese::Table  |       6.2 |                    3.7 |        6.2 | 8.7e-06 |      20 |
- | Zodiac::Chinese         |       5.6 |                    3.1 |        6.9 | 1.2e-05 |      20 |
- | Zodiac::Tiny            |       3.3 |                    0.8 |       12   | 1.2e-05 |      20 |
- | perl -e1 (baseline)     |       2.5 |                    0   |       16   | 9.2e-06 |      20 |
- +-------------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant             | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | DateTime::Event::Zodiac | 1.3                          | 4.7                | 18             |      64   |                   58.4 |        1   |   0.00019 |      20 |
+ | Zodiac::Chinese::Table  | 1.1                          | 4.4                | 16             |      11   |                    5.4 |        5.8 |   0.0001  |      21 |
+ | Zodiac::Chinese         | 0.82                         | 4.1                | 16             |      10   |                    4.4 |        6.2 | 4.4e-05   |      20 |
+ | Zodiac::Tiny            | 11                           | 15                 | 51             |       6.7 |                    1.1 |        9.4 | 1.4e-05   |      20 |
+ | perl -e1 (baseline)     | 0.94                         | 4.3                | 16             |       5.6 |                    0   |       11   | 1.8e-05   |      20 |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -158,7 +163,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
